==> webkit2gtk_2.18.6.orig.tar.xz: webkitgtk-2.18.6/Source/WebKit/WebProcess/InjectedBundle/API/gtk/DOM/WebKitDOMHTMLParamElement.cpp <==
/*
 *  This file is part of the WebKit open source project.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */

#include "config.h"
#include "WebKitDOMHTMLParamElement.h"

#include <WebCore/CSSImportRule.h>
#include "DOMObjectCache.h"
#include <WebCore/DOMException.h>
#include <WebCore/Document.h>
#include "GObjectEventListener.h"
#include <WebCore/HTMLNames.h>
#include <WebCore/JSMainThreadExecState.h>
#include "WebKitDOMEventPrivate.h"
#include "WebKitDOMEventTarget.h"
#include "WebKitDOMHTMLParamElementPrivate.h"
#include "WebKitDOMNodePrivate.h"
#include "WebKitDOMPrivate.h"
#include "ConvertToUTF8String.h"
#include <wtf/GetPtr.h>
#include <wtf/RefPtr.h>

namespace WebKit {

WebKitDOMHTMLParamElement* kit(WebCore::HTMLParamElement* obj)
{
    return WEBKIT_DOM_HTML_PARAM_ELEMENT(kit(static_cast<WebCore::Node*>(obj)));
}

WebCore::HTMLParamElement* core(WebKitDOMHTMLParamElement* request)
{
    return request ? static_cast<WebCore::HTMLParamElement*>(WEBKIT_DOM_OBJECT(request)->coreObject) : 0;
}

WebKitDOMHTMLParamElement* wrapHTMLParamElement(WebCore::HTMLParamElement* coreObject)
{
    ASSERT(coreObject);
    return WEBKIT_DOM_HTML_PARAM_ELEMENT(g_object_new(WEBKIT_DOM_TYPE_HTML_PARAM_ELEMENT, "core-object", coreObject, nullptr));
}

} // namespace WebKit

static gboolean webkit_dom_html_param_element_dispatch_event(WebKitDOMEventTarget* target, WebKitDOMEvent* event, GError** error)
{
    WebCore::Event* coreEvent = WebKit::core(event);
    if (!coreEvent)
        return false;
    WebCore::HTMLParamElement* coreTarget = static_cast<WebCore::HTMLParamElement*>(WEBKIT_DOM_OBJECT(target)->coreObject);

    auto result = coreTarget->dispatchEventForBindings(*coreEvent);
    if (result.hasException()) {
        auto description = WebCore::DOMException::description(result.releaseException().code());
        g_set_error_literal(error, g_quark_from_string("WEBKIT_DOM"), description.legacyCode, description.name);
        return false;
    }
    return result.releaseReturnValue();
}

static gboolean webkit_dom_html_param_element_add_event_listener(WebKitDOMEventTarget* target, const char* eventName, GClosure* handler, gboolean useCapture)
{
    WebCore::HTMLParamElement* coreTarget = static_cast<WebCore::HTMLParamElement*>(WEBKIT_DOM_OBJECT(target)->coreObject);
    return WebKit::GObjectEventListener::addEventListener(G_OBJECT(target), coreTarget, eventName, handler, useCapture);
}

static gboolean webkit_dom_html_param_element_remove_event_listener(WebKitDOMEventTarget* target, const char* eventName, GClosure* handler, gboolean useCapture)
{
    WebCore::HTMLParamElement* coreTarget = static_cast<WebCore::HTMLParamElement*>(WEBKIT_DOM_OBJECT(target)->coreObject);
    return WebKit::GObjectEventListener::removeEventListener(G_OBJECT(target), coreTarget, eventName, handler, useCapture);
}

static void webkit_dom_event_target_init(WebKitDOMEventTargetIface* iface)
{
    iface->dispatch_event = webkit_dom_html_param_element_dispatch_event;
    iface->add_event_listener = webkit_dom_html_param_element_add_event_listener;
    iface->remove_event_listener = webkit_dom_html_param_element_remove_event_listener;
}

G_DEFINE_TYPE_WITH_CODE(WebKitDOMHTMLParamElement, webkit_dom_html_param_element, WEBKIT_DOM_TYPE_HTML_ELEMENT, G_IMPLEMENT_INTERFACE(WEBKIT_DOM_TYPE_EVENT_TARGET, webkit_dom_event_target_init))

enum {
    PROP_0,
    PROP_NAME,
    PROP_TYPE,
    PROP_VALUE,
    PROP_VALUE_TYPE,
};

static void webkit_dom_html_param_element_set_property(GObject* object, guint propertyId, const GValue* value, GParamSpec* pspec)
{
    WebKitDOMHTMLParamElement* self = WEBKIT_DOM_HTML_PARAM_ELEMENT(object);

    switch (propertyId) {
    case PROP_NAME:
        webkit_dom_html_param_element_set_name(self, g_value_get_string(value));
        break;
    case PROP_TYPE:
        webkit_dom_html_param_element_set_type_attr(self, g_value_get_string(value));
        break;
    case PROP_VALUE:
        webkit_dom_html_param_element_set_value(self, g_value_get_string(value));
        break;
    case PROP_VALUE_TYPE:
        webkit_dom_html_param_element_set_value_type(self, g_value_get_string(value));
        break;
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, propertyId, pspec);
        break;
    }
}

static void webkit_dom_html_param_element_get_property(GObject* object, guint propertyId, GValue* value, GParamSpec* pspec)
{
    WebKitDOMHTMLParamElement* self = WEBKIT_DOM_HTML_PARAM_ELEMENT(object);

    switch (propertyId) {
    case PROP_NAME:
        g_value_take_string(value, webkit_dom_html_param_element_get_name(self));
        break;
    case PROP_TYPE:
        g_value_take_string(value, webkit_dom_html_param_element_get_type_attr(self));
        break;
    case PROP_VALUE:
        g_value_take_string(value, webkit_dom_html_param_element_get_value(self));
        break;
    case PROP_VALUE_TYPE:
        g_value_take_string(value, webkit_dom_html_param_element_get_value_type(self));
        break;
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, propertyId, pspec);
        break;
    }
}

static void webkit_dom_html_param_element_class_init(WebKitDOMHTMLParamElementClass* requestClass)
{
    GObjectClass* gobjectClass = G_OBJECT_CLASS(requestClass);
    gobjectClass->set_property = webkit_dom_html_param_element_set_property;
    gobjectClass->get_property = webkit_dom_html_param_element_get_property;

    g_object_class_install_property(
        gobjectClass,
        PROP_NAME,
        g_param_spec_string(
            "name",
            "HTMLParamElement:name",
            "read-write gchar* HTMLParamElement:name",
            "",
            WEBKIT_PARAM_READWRITE));

    g_object_class_install_property(
        gobjectClass,
        PROP_TYPE,
        g_param_spec_string(
            "type",
            "HTMLParamElement:type",
            "read-write gchar* HTMLParamElement:type",
            "",
            WEBKIT_PARAM_READWRITE));

    g_object_class_install_property(
        gobjectClass,
        PROP_VALUE,
        g_param_spec_string(
            "value",
            "HTMLParamElement:value",
            "read-write gchar* HTMLParamElement:value",
            "",
            WEBKIT_PARAM_READWRITE));

    g_object_class_install_property(
        gobjectClass,
        PROP_VALUE_TYPE,
        g_param_spec_string(
            "value-type",
            "HTMLParamElement:value-type",
            "read-write gchar* HTMLParamElement:value-type",
            "",
            WEBKIT_PARAM_READWRITE));

}

static void webkit_dom_html_param_element_init(WebKitDOMHTMLParamElement* request)
{
    UNUSED_PARAM(request);
}

gchar* webkit_dom_html_param_element_get_name(WebKitDOMHTMLParamElement* self)
{
    WebCore::JSMainThreadNullState state;
    g_return_val_if_fail(WEBKIT_DOM_IS_HTML_PARAM_ELEMENT(self), 0);
    WebCore::HTMLParamElement* item = WebKit::core(self);
    gchar* result = convertToUTF8String(item->getNameAttribute());
    return result;
}

void webkit_dom_html_param_element_set_name(WebKitDOMHTMLParamElement* self, const gchar* value)
{
    WebCore::JSMainThreadNullState state;
    g_return_if_fail(WEBKIT_DOM_IS_HTML_PARAM_ELEMENT(self));
    g_return_if_fail(value);
    WebCore::HTMLParamElement* item = WebKit::core(self);
    WTF::String convertedValue = WTF::String::fromUTF8(value);
    item->setAttributeWithoutSynchronization(WebCore::HTMLNames::nameAttr, convertedValue);
}

gchar* webkit_dom_html_param_element_get_type_attr(WebKitDOMHTMLParamElement* self)
{
    WebCore::JSMainThreadNullState state;
    g_return_val_if_fail(WEBKIT_DOM_IS_HTML_PARAM_ELEMENT(self), 0);
    WebCore::HTMLParamElement* item = WebKit::core(self);
    gchar* result = convertToUTF8String(item->attributeWithoutSynchronization(WebCore::HTMLNames::typeAttr));
    return result;
}

void webkit_dom_html_param_element_set_type_attr(WebKitDOMHTMLParamElement* self, const gchar* value)
{
    WebCore::JSMainThreadNullState state;
    g_return_if_fail(WEBKIT_DOM_IS_HTML_PARAM_ELEMENT(self));
    g_return_if_fail(value);
    WebCore::HTMLParamElement* item = WebKit::core(self);
    WTF::String convertedValue = WTF::String::fromUTF8(value);
    item->setAttributeWithoutSynchronization(WebCore::HTMLNames::typeAttr, convertedValue);
}

gchar* webkit_dom_html_param_element_get_value(WebKitDOMHTMLParamElement* self)
{
    WebCore::JSMainThreadNullState state;
    g_return_val_if_fail(WEBKIT_DOM_IS_HTML_PARAM_ELEMENT(self), 0);
    WebCore::HTMLParamElement* item = WebKit::core(self);
    gchar* result = convertToUTF8String(item->attributeWithoutSynchronization(WebCore::HTMLNames::valueAttr));
    return result;
}

void webkit_dom_html_param_element_set_value(WebKitDOMHTMLParamElement* self, const gchar* value)
{
    WebCore::JSMainThreadNullState state;
    g_return_if_fail(WEBKIT_DOM_IS_HTML_PARAM_ELEMENT(self));
    g_return_if_fail(value);
    WebCore::HTMLParamElement* item = WebKit::core(self);
    WTF::String convertedValue = WTF::String::fromUTF8(value);
    item->setAttributeWithoutSynchronization(WebCore::HTMLNames::valueAttr, convertedValue);
}

gchar* webkit_dom_html_param_element_get_value_type(WebKitDOMHTMLParamElement* self)
{
    WebCore::JSMainThreadNullState state;
    g_return_val_if_fail(WEBKIT_DOM_IS_HTML_PARAM_ELEMENT(self), 0);
    WebCore::HTMLParamElement* item = WebKit::core(self);
    gchar* result = convertToUTF8String(item->attributeWithoutSynchronization(WebCore::HTMLNames::valuetypeAttr));
    return result;
}

void webkit_dom_html_param_element_set_value_type(WebKitDOMHTMLParamElement* self, const gchar* value)
{
    WebCore::JSMainThreadNullState state;
    g_return_if_fail(WEBKIT_DOM_IS_HTML_PARAM_ELEMENT(self));
    g_return_if_fail(value);
    WebCore::HTMLParamElement* item = WebKit::core(self);
    WTF::String convertedValue = WTF::String::fromUTF8(value);
    item->setAttributeWithoutSynchronization(WebCore::HTMLNames::valuetypeAttr, convertedValue);
}

==> webkit2gtk_2.20.1.orig.tar.xz: webkitgtk-2.20.1/Source/WebKit/WebProcess/InjectedBundle/API/gtk/DOM/WebKitDOMHTMLParamElement.cpp <==
/*
 *  This file is part of the WebKit open source project.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */

#include "config.h"
#include "WebKitDOMHTMLParamElement.h"

#include <WebCore/CSSImportRule.h>
#include "DOMObjectCache.h"
#include <WebCore/DOMException.h>
#include <WebCore/Document.h>
#include "GObjectEventListener.h"
#include <WebCore/HTMLNames.h>
#include <WebCore/JSMainThreadExecState.h>
#include "WebKitDOMEventPrivate.h"
#include "WebKitDOMEventTarget.h"
#include "WebKitDOMHTMLParamElementPrivate.h"
#include "WebKitDOMNodePrivate.h"
#include "WebKitDOMPrivate.h"
#include "ConvertToUTF8String.h"
#include <wtf/GetPtr.h>
#include <wtf/RefPtr.h>

namespace WebKit {

WebKitDOMHTMLParamElement* kit(WebCore::HTMLParamElement* obj)
{
    return WEBKIT_DOM_HTML_PARAM_ELEMENT(kit(static_cast<WebCore::Node*>(obj)));
}

WebCore::HTMLParamElement* core(WebKitDOMHTMLParamElement* request)
{
    return request ? static_cast<WebCore::HTMLParamElement*>(WEBKIT_DOM_OBJECT(request)->coreObject) : 0;
}

WebKitDOMHTMLParamElement* wrapHTMLParamElement(WebCore::HTMLParamElement* coreObject)
{
    ASSERT(coreObject);
    return WEBKIT_DOM_HTML_PARAM_ELEMENT(g_object_new(WEBKIT_DOM_TYPE_HTML_PARAM_ELEMENT, "core-object", coreObject, nullptr));
}

} // namespace WebKit

static gboolean webkit_dom_html_param_element_dispatch_event(WebKitDOMEventTarget* target, WebKitDOMEvent* event, GError** error)
{
    WebCore::Event* coreEvent = WebKit::core(event);
    if (!coreEvent)
        return false;
    WebCore::HTMLParamElement* coreTarget = static_cast<WebCore::HTMLParamElement*>(WEBKIT_DOM_OBJECT(target)->coreObject);

    auto result = coreTarget->dispatchEventForBindings(*coreEvent);
    if (result.hasException()) {
        auto description = WebCore::DOMException::description(result.releaseException().code());
        g_set_error_literal(error, g_quark_from_string("WEBKIT_DOM"), description.legacyCode, description.name);
        return false;
    }
    return result.releaseReturnValue();
}

static gboolean webkit_dom_html_param_element_add_event_listener(WebKitDOMEventTarget* target, const char* eventName, GClosure* handler, gboolean useCapture)
{
    WebCore::HTMLParamElement* coreTarget = static_cast<WebCore::HTMLParamElement*>(WEBKIT_DOM_OBJECT(target)->coreObject);
    return WebKit::GObjectEventListener::addEventListener(G_OBJECT(target), coreTarget, eventName, handler, useCapture);
}

static gboolean webkit_dom_html_param_element_remove_event_listener(WebKitDOMEventTarget* target, const char* eventName, GClosure* handler, gboolean useCapture)
{
    WebCore::HTMLParamElement* coreTarget = static_cast<WebCore::HTMLParamElement*>(WEBKIT_DOM_OBJECT(target)->coreObject);
    return WebKit::GObjectEventListener::removeEventListener(G_OBJECT(target), coreTarget, eventName, handler, useCapture);
}

static void webkit_dom_html_param_element_dom_event_target_init(WebKitDOMEventTargetIface* iface)
{
    iface->dispatch_event = webkit_dom_html_param_element_dispatch_event;
    iface->add_event_listener = webkit_dom_html_param_element_add_event_listener;
    iface->remove_event_listener = webkit_dom_html_param_element_remove_event_listener;
}

G_DEFINE_TYPE_WITH_CODE(WebKitDOMHTMLParamElement, webkit_dom_html_param_element, WEBKIT_DOM_TYPE_HTML_ELEMENT, G_IMPLEMENT_INTERFACE(WEBKIT_DOM_TYPE_EVENT_TARGET, webkit_dom_html_param_element_dom_event_target_init))

enum {
    DOM_HTML_PARAM_ELEMENT_PROP_0,
    DOM_HTML_PARAM_ELEMENT_PROP_NAME,
    DOM_HTML_PARAM_ELEMENT_PROP_TYPE,
    DOM_HTML_PARAM_ELEMENT_PROP_VALUE,
    DOM_HTML_PARAM_ELEMENT_PROP_VALUE_TYPE,
};

static void webkit_dom_html_param_element_set_property(GObject* object, guint propertyId, const GValue* value, GParamSpec* pspec)
{
    WebKitDOMHTMLParamElement* self = WEBKIT_DOM_HTML_PARAM_ELEMENT(object);

    switch (propertyId) {
    case DOM_HTML_PARAM_ELEMENT_PROP_NAME:
        webkit_dom_html_param_element_set_name(self, g_value_get_string(value));
        break;
    case DOM_HTML_PARAM_ELEMENT_PROP_TYPE:
        webkit_dom_html_param_element_set_type_attr(self, g_value_get_string(value));
        break;
    case DOM_HTML_PARAM_ELEMENT_PROP_VALUE:
        webkit_dom_html_param_element_set_value(self, g_value_get_string(value));
        break;
    case DOM_HTML_PARAM_ELEMENT_PROP_VALUE_TYPE:
        webkit_dom_html_param_element_set_value_type(self, g_value_get_string(value));
        break;
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, propertyId, pspec);
        break;
    }
}

static void webkit_dom_html_param_element_get_property(GObject* object, guint propertyId, GValue* value, GParamSpec* pspec)
{
    WebKitDOMHTMLParamElement* self = WEBKIT_DOM_HTML_PARAM_ELEMENT(object);

    switch (propertyId) {
    case DOM_HTML_PARAM_ELEMENT_PROP_NAME:
        g_value_take_string(value, webkit_dom_html_param_element_get_name(self));
        break;
    case DOM_HTML_PARAM_ELEMENT_PROP_TYPE:
        g_value_take_string(value, webkit_dom_html_param_element_get_type_attr(self));
        break;
    case DOM_HTML_PARAM_ELEMENT_PROP_VALUE:
        g_value_take_string(value, webkit_dom_html_param_element_get_value(self));
        break;
    case DOM_HTML_PARAM_ELEMENT_PROP_VALUE_TYPE:
        g_value_take_string(value, webkit_dom_html_param_element_get_value_type(self));
        break;
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, propertyId, pspec);
        break;
    }
}

static void webkit_dom_html_param_element_class_init(WebKitDOMHTMLParamElementClass* requestClass)
{
    GObjectClass* gobjectClass = G_OBJECT_CLASS(requestClass);
    gobjectClass->set_property = webkit_dom_html_param_element_set_property;
    gobjectClass->get_property = webkit_dom_html_param_element_get_property;

    g_object_class_install_property(
        gobjectClass,
        DOM_HTML_PARAM_ELEMENT_PROP_NAME,
        g_param_spec_string(
            "name",
            "HTMLParamElement:name",
            "read-write gchar* HTMLParamElement:name",
            "",
            WEBKIT_PARAM_READWRITE));

    g_object_class_install_property(
        gobjectClass,
        DOM_HTML_PARAM_ELEMENT_PROP_TYPE,
        g_param_spec_string(
            "type",
            "HTMLParamElement:type",
            "read-write gchar* HTMLParamElement:type",
            "",
            WEBKIT_PARAM_READWRITE));

    g_object_class_install_property(
        gobjectClass,
        DOM_HTML_PARAM_ELEMENT_PROP_VALUE,
        g_param_spec_string(
            "value",
            "HTMLParamElement:value",
            "read-write gchar* HTMLParamElement:value",
            "",
            WEBKIT_PARAM_READWRITE));

    g_object_class_install_property(
        gobjectClass,
        DOM_HTML_PARAM_ELEMENT_PROP_VALUE_TYPE,
        g_param_spec_string(
            "value-type",
            "HTMLParamElement:value-type",
            "read-write gchar* HTMLParamElement:value-type",
            "",
            WEBKIT_PARAM_READWRITE));

}

static void webkit_dom_html_param_element_init(WebKitDOMHTMLParamElement* request)
{
    UNUSED_PARAM(request);
}

gchar* webkit_dom_html_param_element_get_name(WebKitDOMHTMLParamElement* self)
{
    WebCore::JSMainThreadNullState state;
    g_return_val_if_fail(WEBKIT_DOM_IS_HTML_PARAM_ELEMENT(self), 0);
    WebCore::HTMLParamElement* item = WebKit::core(self);
    gchar* result = convertToUTF8String(item->getNameAttribute());
    return result;
}

void webkit_dom_html_param_element_set_name(WebKitDOMHTMLParamElement* self, const gchar* value)
{
    WebCore::JSMainThreadNullState state;
    g_return_if_fail(WEBKIT_DOM_IS_HTML_PARAM_ELEMENT(self));
    g_return_if_fail(value);
    WebCore::HTMLParamElement* item = WebKit::core(self);
    WTF::String convertedValue = WTF::String::fromUTF8(value);
    item->setAttributeWithoutSynchronization(WebCore::HTMLNames::nameAttr, convertedValue);
}

gchar* webkit_dom_html_param_element_get_type_attr(WebKitDOMHTMLParamElement* self)
{
    WebCore::JSMainThreadNullState state;
    g_return_val_if_fail(WEBKIT_DOM_IS_HTML_PARAM_ELEMENT(self), 0);
    WebCore::HTMLParamElement* item = WebKit::core(self);
    gchar* result = convertToUTF8String(item->attributeWithoutSynchronization(WebCore::HTMLNames::typeAttr));
    return result;
}

void webkit_dom_html_param_element_set_type_attr(WebKitDOMHTMLParamElement* self, const gchar* value)
{
    WebCore::JSMainThreadNullState state;
    g_return_if_fail(WEBKIT_DOM_IS_HTML_PARAM_ELEMENT(self));
    g_return_if_fail(value);
    WebCore::HTMLParamElement* item = WebKit::core(self);
    WTF::String convertedValue = WTF::String::fromUTF8(value);
    item->setAttributeWithoutSynchronization(WebCore::HTMLNames::typeAttr, convertedValue);
}

gchar* webkit_dom_html_param_element_get_value(WebKitDOMHTMLParamElement* self)
{
    WebCore::JSMainThreadNullState state;
    g_return_val_if_fail(WEBKIT_DOM_IS_HTML_PARAM_ELEMENT(self), 0);
    WebCore::HTMLParamElement* item = WebKit::core(self);
    gchar* result = convertToUTF8String(item->attributeWithoutSynchronization(WebCore::HTMLNames::valueAttr));
    return result;
}

void webkit_dom_html_param_element_set_value(WebKitDOMHTMLParamElement* self, const gchar* value)
{
    WebCore::JSMainThreadNullState state;
    g_return_if_fail(WEBKIT_DOM_IS_HTML_PARAM_ELEMENT(self));
    g_return_if_fail(value);
    WebCore::HTMLParamElement* item = WebKit::core(self);
    WTF::String convertedValue = WTF::String::fromUTF8(value);
    item->setAttributeWithoutSynchronization(WebCore::HTMLNames::valueAttr, convertedValue);
}

gchar* webkit_dom_html_param_element_get_value_type(WebKitDOMHTMLParamElement* self)
{
    WebCore::JSMainThreadNullState state;
    g_return_val_if_fail(WEBKIT_DOM_IS_HTML_PARAM_ELEMENT(self), 0);
    WebCore::HTMLParamElement* item = WebKit::core(self);
    gchar* result = convertToUTF8String(item->attributeWithoutSynchronization(WebCore::HTMLNames::valuetypeAttr));
    return result;
}

void webkit_dom_html_param_element_set_value_type(WebKitDOMHTMLParamElement* self, const gchar* value)
{
    WebCore::JSMainThreadNullState state;
    g_return_if_fail(WEBKIT_DOM_IS_HTML_PARAM_ELEMENT(self));
    g_return_if_fail(value);
    WebCore::HTMLParamElement* item = WebKit::core(self);
    WTF::String convertedValue = WTF::String::fromUTF8(value);
    item->setAttributeWithoutSynchronization(WebCore::HTMLNames::valuetypeAttr, convertedValue);
}
